#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-4RNAPcb5ToC53Mx1hvMF8Z
key:                  haskell-language-server-2.3.0.0-4RNAPcb5ToC53Mx1hvMF8Z
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  77d8671012403b9ea833eba2e3b4cacf
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-4RNAPcb5ToC53Mx1hvMF8Z
depends:
    aeson-pretty-0.8.10-Cp5Ev6E5fW8IEHmaGqAkd6
    async-2.2.6-BS84yQ2zVBrDBmVQA7dIRt base-4.18.2.1
    base16-bytestring-1.0.2.0-EQipqCKv7X46z29erFjOBi
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-1jFoW3VxAGuB8crJhpr97k
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-3E6HSCetxI77j4vvrpqBZZ filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-BdMGbpLsskPJ4SXAVctF2x
    githash-0.1.6.3-DOWHjwaNQYs9c98qP6gPdS
    hie-bios-0.12.0-4QPeJccbRhU9h6687KZ3FS
    hiedb-0.4.3.0-2fXtYeQm0OCIvuRclDsn0W
    hls-alternate-number-format-plugin-2.3.0.0-4atWQSfA39bLeK7ASAfG3s
    hls-cabal-fmt-plugin-2.3.0.0-5YlZ8iiZ2R0EUpRV5w4Av2
    hls-cabal-plugin-2.3.0.0-MkpAEduX1SEjYd7DPEKHd
    hls-call-hierarchy-plugin-2.3.0.0-HL5xY0FCPcJFdpeHk6wVo4
    hls-change-type-signature-plugin-2.3.0.0-LoU5kaw5WNNH3sCWo0mQTg
    hls-class-plugin-2.3.0.0-3Kq4uWGIWoQBpeO94c67Y3
    hls-code-range-plugin-2.3.0.0-EOWg5lsgdnnDdk4Pzs0ARW
    hls-eval-plugin-2.3.0.0-LqQth2U05YeI0wVpi2cH2W
    hls-explicit-fixity-plugin-2.3.0.0-5SZmzMTRR9xLE7eHpQ3oTZ
    hls-explicit-imports-plugin-2.3.0.0-4NrLRCFJNpw8RrutvjJJh0
    hls-explicit-record-fields-plugin-2.3.0.0-2MW1LBlCLvK6uCB6hWFtfp
    hls-fourmolu-plugin-2.3.0.0-FS6mpVvWuci98SKMJFBzHa
    hls-gadt-plugin-2.3.0.0-KPXH4ZNTFWvLEg1OlCwB0G
    hls-graph-2.3.0.0-2oIUun4fM8yD8pqzUwzQxt
    hls-hlint-plugin-2.3.0.0-9QHK2kmNa11H88VMdCQf9l
    hls-module-name-plugin-2.3.0.0-FmD8wxYxI8m3mvW8kRK4QK
    hls-ormolu-plugin-2.3.0.0-AgXmy3qNk0KCtfNSf8411A
    hls-overloaded-record-dot-plugin-2.3.0.0-HJBG2OMCLz7EXjnGrWDVNy
    hls-plugin-api-2.3.0.0-LhAFgQznXEBIGY3uBkhgs2
    hls-pragmas-plugin-2.3.0.0-5z2Yq7fS32l576gaGaDqYu
    hls-qualify-imported-names-plugin-2.3.0.0-IhZe5skbRy6CfrfpaPQTib
    hls-refactor-plugin-2.3.0.0-AV4OeiuPkx563TkVY1VUPM
    hls-rename-plugin-2.3.0.0-JRMl5a5IR1aCvLjXjjbtPk
    hls-retrie-plugin-2.3.0.0-2rNY1cjqSzWIPHzmc2qCj0
    hls-splice-plugin-2.3.0.0-ESyBuao3BeV6okAXdIfKVd
    hls-stylish-haskell-plugin-2.3.0.0-6lcuoiqoSYvCB8BNgb6qbw
    lsp-2.2.0.0-Fs8m200E5aw9Sv6zmwOan7
    optparse-applicative-0.18.1.0-FNdMNW8dFFC8ACVK6wiEzg
    optparse-simple-0.1.1.4-LdlVVoRXVcC1thqlBM12W1
    prettyprinter-1.7.1-CrB75FqOuOiDw6pLIzh878 process-1.6.19.0
    safe-exceptions-0.1.7.4-5HbjzD7XOi1j72hHyteTX
    sqlite-simple-0.4.19.0-Lvm2UIScQ9nIsSX4Gnq4Ix text-2.0.2
    unordered-containers-0.2.20.1-9wZ7uB8CqcR5TZZg4U4qth

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

